bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 37. Aventiure
___________________________________________________ #### Aventivre wie rvdeger #### erslagen wart
###### 2135 | ### Ez heten di ellende | wider morgen gvt getan ### wine der gotelinde | chom ce hove gegan ### do sach er beidenthalben | div grozlicher ser ### daz weinte innechlichen | der vil gvte rvdeger
###### 2136 | ### so we mir sprach der recke | daz ich ie den lip gewan ### daz disen grozen iamer | chan niemen vnderstan ### swi gerne ichz vriden wolde | der chvenech en tvt es niht ### wande er der sine leide | ie mer vnd mer gesiht
###### 2137 | ### do sande an dieterichen | der gvte rvedeger ### ob siz noch chvnden wenden | an den chvenegen her ### do enbot im der von berne | wer moht iz vnderstan ### ez en wil der kvenech ecel | niemen scheiden lan
###### 2138 | ### do sah ein hivnen recke | rvedgeren stan ### mit weinenden ovgen | vnde hetes vil getan ### der sprach cer kveneginne | nv seht ir wi er stat ### der doch gewalt den meisten | hi bi eceln hat
###### 2139 | ### vnt dem allez dienet | livt vnde lant ### wi so vil der bverge | an rvedeger gewant ### der er von dem chvenege | vil manege haben mach ### er geslvch in disen stvermen | nie lobelichen slach
###### 2140 | ### mich dvnchet ern rvche | wi ez hi vmbe gat ### sit er der vollen | nach sinem willen hat ### man giht im er si chvener | danne iemen mvege sin ### daz ist in disen sorgen | worden bosliche schin
###### 2141 | ### mit trvrigem mvte | der vil getriwe man ### den er daz reden horte | der helt der blicht in an ### er dahte dv solt ez erarnen | dv gihest ich si verzagt ### dv hast disiv maere | ce hove ce lvte gesagt
###### 2142 | ### di fvst begonder twingen | do lief er in an ### vnde slvch so chrepftliche | den hivnisschen man ### daz er im vor den fvzen | lach vil shier tot ### do was aber gemeret | des kvenech eceln not
###### 2143 | ### hin du zage maere | sprach do rvedger ### hich han doch genvge | leit vnde ser ### daz ich hi niht en vihte | zwiv wizest dv mir daz ### ia waere ich den gesten | von grozen schvlden gehaz
###### 2144 | ### vnde allez daz ich moehte | het ich in getan ### niwan daz ich di recken | her gefveret han ### ia was ich ir geleite | in mines herren lant ### des en sol mit in niht striten | min vil ellendes hant
###### 2145 | ### do sprach ce dem margraven | ecel der kvenech her ### wi habt ir vns geholfen | vil edel rvedeger ### wand wir so vil der viegen | hi ce lande han ### wir bedorften ir niht mere | ir habt vil vebele getan
###### 2146 | ### do sprach der ritter edele | da besweret er mir den mvt ### vnde hat mich geitewizet | ere vnde gvt ### des ich von dinen handen | han so vil genomen ### daz ist dem lvgenaere | ein teil vnstaeteliche chomen
###### 2147 | ### do chom div chveneginne | vnde het iz ovch gesehen ### daz von des heldes zorne | dem hivnen was geschehen ### si chlagetez vngefvge | ir ovgen wurden naz ### si sprach ce rvedegere | wi habe wir verdienet daz
###### 2148 | ### daz ir mir vnt dem chvenege | meret vnser leit ### nv habt ir vns edel rvedger | allez her geseit ### ir woldet dvrh vns wagen | di ere vnde ovch daz leben ### ich hort iv vil der recken | den pris vil groezlichen geben
###### 2149 | ### ich man ivch der genaden | vnd ir mir habt gesworn ### do ir mir ce eceln rietet | ritter vzerchorn ### daz ir mir woldet dienen | an vnser eines tot ### des wart mir armem wibe | nie so grozliche not
###### 2150 | ### daz ist ane lovgen | ich swuor iv edel wip ### daz ich dvrch ivch wagete | ere vnde ovch den lip ### daz ich di sele vliese | des en han ich niht gesworn ### zv dirre hohgezite | bat ich di fversten wol geborn
###### 2151 | ### si sprach gedenche rvedger | der grozen triwe din ### der staete vnd ovch der eide | daz dv den schaden min ### immer woldest rechen | vnd elliv miniv leit ### do sprach der margrave | ich han iv selten verseit
###### 2152 | ### ecel der vil riche | vlegen ovch began ### do bvten si sich ce fvzen | beide fver den man ### den edelen margraven | vnmvtes man do sach ### der vil getriwe recke | harte iamerlichen sprach
###### 2153 | ### owe mir gotes armem | daz ich ie dice gelebet han ### aller miner eren | der mvz ich abe stan ### triwen vnde zvehte | der got an mir gebot ### owe got von himele | daz mich es niht wendet der tot
###### 2154 | ### swelhez ich nv laze vnt | daz ander began ### so han ich bosliche | vnde vil vbele getan ### laze aber ich si beide | mich schiltet elliv diet ### nv gervche mich bewisen | der mir ce lebene geriet
###### 2155 | ### do baten sin in genote | der chvenech vnd ovch sin wip ### si mvsen sider rechen | verliesen den lip ### vor rvedgeres hende | da ovch der helt erstarp ### ir mveget daz hi wol hoeren | daz er vil iamerlichen warp
###### 2156 | ### er wiste schaden gewinnen | vnd vngefvgiv leit ### et het dem chvenege | vil gerne verseit ### vnd ovch der chveneginne | vil sere vorhte er daz ### ob er ir einen slvege | daz im div werlt wuerde gehaz
###### 2157 | ### do sprach zv dem chvenege | der vil chvene man ### her kvenech nv nemt hin widere | al daz ich von iv han ### daz lant mit den bvergen | der sol mir niht bestan ### ich wil vf minen fvzen | in daz ellende gan
###### 2158 | ### do sprach der kvenech ecel | wer hvelfe danne mir ### daz lant zv den livten | daz gib ich allez dir ### daz dv mich rechest rvedger | an den vienden min ### dv solt ein kvenech gewaltech | beneben eceln sin
###### 2159 | ### do sprach aber rvedger | wi sol iz ane van ### heim zv minem hvse | ich si galaden han ### trinchen vnd spise | ich in gvetlichen bot ### vnd gab in mine gabe | wi sol ich raten in den tot
###### 2160 | ### di livte waenent lihte | daz ich si verzaget ### deheinen minen dienest | han ich in versaget ### den vil edeln fversten | vnt den iren man ### ovch riwet mich div vrivntschaft | di ich mit in geworben han
###### 2161 | ### giselher dem degene | gab ich di tohter min ### si ne chvnde in dirre werlde | niht baz verwendet sin ### vf zvht vnde vf ere | vf triwe vnde ovch vf gvt ### ine gesach ni kvenech so ivngen | so tvgentlich gemvt
###### 2162 | ### do sprach aber criemhilt | vil edel rvedger ### nv la dich erbarmen | vnser beider ser ### min vnde ovch des kveneges | gedenche wol daran ### daz nie wirt deheiner | so leide geste gewan
###### 2163 | ### do sprach der margrave | wider daz edel wip ### ez mvz hivte gelten | der rvedegeres lip ### swaz ir vnd ovch min herre | mir liebes habt getan ### darvmbe mvz ich ersterben | daz mag niht langer gestan
###### 2164 | ### ich weiz wol daz noch hivte | mine bverge vnde miniv lant ### iv mvezen ledech werden | von ir eteliches hant ### ich bevilhiv vf genade | min wip vnde miniv kint ### vnd ovch di vil ellenden | di da ce bechelaren sint
###### 2165 | ### nv lon dir got rvedeger | sprach der kvenech do ### er vnt div chvneginne | si wurden beide vro ### vns svln dine livte | vil wol bevolhen wesen ### wol truwe ich minem heile | dv maht selbe genesen
###### 2166 | ### nv liez er an di wage | sele vnd lip ### do begonde weinen | daz ecelen wip ### er sprach ich mvz iv leisten | als ich gelobt han ### owe der minen frivnde | di ich vil vngerne bestan
###### 2167 | ### man sah in von dem chvenege | vil trvrechlichen gen ### do vande er sine recken | vil nahen vor im sten ### er sprach ir svlt ivch waffen | alle mine man ### di chvenen bvrgonden | di mvz ich leider bestan
###### 2168 | ### si hiezen balde springen | da man ir geweffen vant ### ez der helm waere | oder des schildes rant ### von ir ingesinde wart | ez dar getragen ### sit horten leidiv maere | di stolzen ellenden sagen
###### 2169 | ### gewaffent wart do rvedger | mit fvnf hvndert man ### darveber zwelf recken | ce helfe er do gewan ### di wolden pris erwerben | in des stvrmes not ### sin wessen niht des | daz in so nahete der tot
###### 2170 | ### do sah man rvedegeren | vnder helm gan ### ez trvgen swert div sharpfen | di rvedegeres man ### darzv vor ir handen | di liehten schilde breit ### daz sach der videlaere | ez was im groezliche leit
###### 2171 | ### do sah der ivnge giselher | sinen sweher gen ### mit vf gebvndem helme | wi moht er do versten ### waz er da meinte | niwan allez gvt ### des wart der kvenech edele | so rehte vroelich gemvt
###### 2172 | ### nv wol mich solher vrivnt | sprach giselher der degen ### di wir han gewunnen | vfn disen wegen ### wir svln mines wibes | vil wol genizzen hie ### mir ist lieb vf mine triwe | daz ie div hirat ergie
###### 2173 | ### ine weiz wes ir ivch troestet | sprah do der spilman ### wa gesahet ie dvrh svne | so manegen helt gan ### mit vf gebvnden helmen | di trvegen swert enhant ### an vns wil dienen rvedeger | sine bverge vnd siniv lant
###### 2174 | ### bedaz der videlaere | di rede vol gesprach ### rvedegern den edeln | man vor dem hvse sach ### sinen schilt den gvten | satzet er fver den fvz ### do mvs er sinen frivnden | versagen dienest vnd grvz
###### 2175 | ### der edel margrave | rief in den sal ### ir chvenen nibelvnge | nv wert ivch vber al ### ir soldet min geniezen | nv engeltet ir min ### e do waren wir vrivnde | der triwen wil ih ledech sin
###### 2176 | ### do erscrachten dirre maere | di nothafen man ### wande ir deheiner vrevden | davon niht gewan ### daz mit in wolde striten | dem si da waren holt ### si heten von ir vienden | michel arbeit gedolt
###### 2177 | ### nv ne welle got von himele | sprach gventher der degen ### daz ir ivch genaden | svlt an vns bewegen ### vnt der vil grozen triwe | der wir doch heten mvt ### ich wil iv des getruwen | daz irz nimmer getvt
###### 2178 | ### ia ne mach ich es niht gelazen | sprah do der chvene man ### ich mvz mit iv striten | wand ich ez gelobt han ### nv wert ivch chvnen helde | so lieb iv si der lip ### mich en woldes niht erlazen | des kvenech eceln wip
###### 2179 | ### ir widersagt vns nv ce spate | sprah do der kvnech her ### nv mvez iv got vergelten | vil edel rvedeger ### triwe vnde minne | di ir vns habt getan ### ob irz an dem ende | woldet gvetlich erlan
###### 2180 | ### wir soldenz immer dienen | daz ir vns habt gegeben ### ir vnde mine mage | ob ir vns liezet leben ### der herlichen gabe | di ir vns brahtet her ### in eceln lant mit triwen | des denchet edel rvedger
###### 2181 | ### wi wol ich iv des gvnde | sprach rvedger der degen ### daz ich iv mine gabe | mit vollen solde geben ### also willechlichen | als ich des hete wan ### so ne wurde mir darvmbe | nimmer schelten getan
###### 2182 | ### erwindet edel rvedeger | sprach do gernot ### wand ez wirt deheiner | gesten nie erbot ### so rehte minnechlichen | so ir vns habt getan ### des svlt ir wol geniezen | ob wir bi lebene bestan
###### 2183 | ### daz wolde got sprach rvedger | vil edel gernot ### daz ir ce rine waeret | vnde ich waere tot ### mit etelichen eren | sit ich ivch sol bestan ### ez en wart noch nie an helden | wirs von frivnden getan
###### 2184 | ### nv lon iv got her rvedger | sprach aber gernot ### der vil richen gabe | mich riwet iwer tot ### sol an iv verderben | so tvgentlicher mvt ### hi trage ich iwer waffen | daz ir mir gabet helt gvt
###### 2185 | ### daz ist mir nie geswichen | in aller dirre not ### vnder sinen ecken | lit manich ritter tot ### ez ist lvter vnde staete | herlich vnd gvt ### ich waene so richer gabe | ein recke nimmer mer getvt
###### 2186 | ### vnde welt ir niht erwinden | irn welt zv zvns gan ### slaht ir mir iht der vrivnde | di ich noh hinne han ### mit iwer selbes swerte | nim ich iv den lip ### so riwet ir mich rvedeger | vnde iwer herlich wip
###### 2187 | ### daz wolde got her gernot | vnde moeht daz ergan ### daz aller iwer wille | waere hi getan ### vnt daz genesen waere | iwerr frivnde lip ### ia sol iv wol getrvtet beide | min tohter vnde min wip
###### 2188 | ### do sprach von bvrgonden | der shoenen vten chint ### wi tvt ir so her rvedeger | di mit mir chomen sint ### di sint iv alle waege | ir grifet vebel zv ### di iwern shonen tohter | welt ir verwitwen ce frv
###### 2189 | ### swenne ir vnd iwer rechen | mit strite mich bestat ### wi rehte vnvrivntliche | ir daz schinen lat ### daz ich iv wol getruwe | fver alle ander man ### davon ich zeinem wibe | iwer tohter mir gewan
###### 2190 | ### gedenchet iwer triwe | vil edel kvnech her ### gesende ivch got von hinnen | so sprach rvedger ### lat di ivnchvrowen | niht engeltn min ### dvrch iwer selbes tvgende | so rvchet ir genaedech sin
###### 2191 | ### daz taet ich pillichen | sprach giseher daz chint ### di hohen mine mage | di noch hirinne sint ### svln di vor iv ersterben | so mvz gescheiden sin ### div vil staete vrivntschapft zv dir | vnd ovch der tohter din
###### 2192 | ### nv mvez vns got genaden | sprah der chvene man ### do hvoben si di schilde | also si wolden dan ### striten zv den gesten | in criemhilde sal ### do rief vil lvte hagene | von der stiegen her ce tal
###### 2193 | ### belibet eine wile | vil edel rvedger ### also sprach do hagene | wir wolden reden mer ### ich vnd mine herren | als vns des twinget not ### waz mach gehelfen eceln | vnser ellenden tot
###### 2194 | ### ich sten in grozen sorgen | sprach aber hagene ### den schilt den mir gab | vrov gotelint ce tragene ### den habent mir di hivnen | cerhowen vor der hant ### ich friwentliche | in daz eceln lant
###### 2195 | ### daz des got von himele | gervchen wolde ### daz ich schilt so gvten | noch tragen solde ### so den dv hast vor hende | vil edel rvedeger ### so bedorft ich in den stvermen | deheiner halsperge mer
###### 2196 | ### vil gerne ich dir waere gvt | mit minem schilde ### torst ich dirn bieten | vor criemhilde ### doch nim dv in hin hagene | vnt tragen an der hant ### hey soldestv in fveren | heim in der bvrgonden lant
###### 2197 | ### do er im so willechlichen | den schilt ce gebene bot ### do wart genvger ovgen | von heizen traehen rot ### ez was div leste gabe | di sit immer mer ### gebot deheinem degene | von bechelaren rvedeger
###### 2198 | ### swi grimme hagen waere | vnd swi herte gemvt ### ia erbarmte im div gabe | di der helt gvt ### bi sinen lesten ziten | so nahen het getan ### vil manech ritter edele | mit im trvren began
###### 2199 | ### nv lon iv got von himele | vil edel rvdger ### ez wirt iwer gelichen | deheiner nimmer mer ### der ellenden recken | so herliche geb ### got sol daz gebieten | daz iwer tvgent immer leb
###### 2200 | ### so we mir dirre maere | sprach aber hagene ### wir heten ander swaere | so vil ce tragene ### svln wir mit frivnden striten | daz si got gechleit ### do sprach der margrave | daz ist mir innechlichen leit
###### 2201 | ### nv lon iv got der gabe | vil edel rvedeger ### swi halt gein iv gebaren | dise recken her ### daz nimmer ivch gerveret | in strite hi min hant ### ob ir si alle slveget | di von bvrgonden lant
###### 2202 | ### des neig im mit zvehten | der gvte rvedeger ### si weinten allenthalben | daz disiv hercen ser ### niemen gescheiden chvnde | daz was ein michel not ### vater maneger tvgende | lach an rvedgeren tot
###### 2203 | ### do sprach von dem hvse | volker der spilman ### sit min geselle hagene | den fride hat getan ### den svlt ovch ir staete | haben von miner hant ### daz habt ir wol verdienet | do wir chomen in daz lant
###### 2204 | ### vil edel margrave | ir svlt min bote sin ### dise roten bovge | gap mir div margravin ### daz ich si tragen solde | hi cer hogezit ### di mveget ir selbe schoven | daz ir min gezivch des sit
###### 2205 | ### daz wolde got von himele | sprach do rvedeger ### daz iv div margravinne | noch solde geben mer ### div maere sag ich gerne | der trivtinne min ### gesihe ich si gesvnde | des mvegt ir ane zwivel sin
###### 2206 | ### als er im daz gelobte | den schilt hvp rvedeger ### des mvotes er retobete | do ne beit er da niht mer ### do lief er zv den gesten | einem degen gelich ### manegen slach vil swinden | slvch der margrave rich
###### 2207 | ### di zwene stvnden hoher | volker vnd hagene ### wand ez im e gelobten | di chvenen degene ### noch vand er also chvenen | bi dem tvrne stan ### daz rvedeger des strites | mit grozen sorgen began
###### 2208 | ### dvrch mortrachen willen | so liezen in dar in ### gventher vnd gernot | si heten helde sin ### do stvnt vf hoher giselher | zware ez was im leit ### er versach sich noch des lebenes | darvmb er rvedgern meit
###### 2209 | ### do sprachen zv den fienden | des margraven man ### man sach si nach ir herren | vil degenliche gan ### div snidenden waffen | si trvgen an der hant ### des brast da vil der helme | vnd manech herlicher rant
###### 2210 | ### do slvgen di vil mveden | manegen herten slach ### den von bechelaren | der eben vnd tiefe wach ### dvrch di liehten ringe | vaste vnz vf daz verch ### si taten in dem stvrme | div vil herlichen werch
###### 2211 | ### daz edel ingesinde was | nv chomen gar dar in ### volker vnd hagene | di sprvngen balde hin ### si ne gaben vride niemen | wan dem einem man ### von ir beider handen | daz plvot dvrh helme nider ran
###### 2212 | ### wi rehte grimmechlichen | vil manech swert darinne erchlanch ### vil der schilde spangen | vz den slegen spranch ### des reis ir schiltgesteine | verhowen in daz plvot ### si vahten also grimme | daz man ez nimmer mer getvt
###### 2213 | ### der vogt von bechlaren | gie wider vnd dan ### also der mit ellen | in stvrme werben chan ### dem tet des tages rvedeger | harte wol gelich ### daz er ein recke waere | vil chvne vnt ovh vil lobelich
###### 2214 | ### hi stvnden dise recken | gvnther vnde gernot ### si slvgen in dem stvrme | vil manegen helt tot ### giselher vnt danchwart | di zwen ez ringe wach ### des frvmten si vil manegen | vnz vf ir ivngesten tach
###### 2215 | ### vil wol zeigete rvedeger | daz er was starch genvch ### chvene vnde wol gewaffent | hey waz er helde slvch ### daz sach ein bvrgonde | zornes gie im not ### davon begvnde nahen | des edeln rvedgeres tot
###### 2216 | ### gernot der starche | den helt rvft er an ### er sprach cem margraven | ir welt mir miner man ### niht genesen lazen | vil edel rvedger ### daz mvet mich ane maze | ichn chans niht angesehen mer
###### 2217 | ### nv mag iv iwer gabe | wol ce shaden chomen ### sit ir mir miner vrivnde | habt so vil genomen ### nv wendet ivch her vmbe | vil edel chvene man ### iwer gabe wirt verdienet | so ich allerbeste chan
###### 2218 | ### e daz der margrave | zv zim vol chom dar ### des mvsen liehte ringe | werden missevar ### do sprvngen zv einander | di ere gernde man ### ir ietwederr schermen | fver starche wunden began
###### 2219 | ### ir swert so scherpfe waren | ez en chvnde niht gewegen ### do slvch gernoten | rvedeger der degen ### dvrch helme vlins herten | daz nider vloz daz plvt ### daz vergalt im schiere | der ritter chvene vnd gvt
###### 2220 | ### di rvedegeres gabe | an hende er hohe wach ### swi wunt er cem tode waere | er slvch im einen slach ### dvrch den schilt vil gvten | vnz vf div helm gespan ### davon so mvs ersterben | der schoenen gotelinde man
###### 2221 | ### ia ne wart ni wirs gelonet | so richer gabe mer ### do vielen beide erslagene | gernot vnd rvedeger ### gelich in dem stvrme | von ir beider hant ### allererst erzvrnede hagene | do er den grozen schaden vant
###### 2222 | ### do sprach der helt von tronege | ez ist vns vebel chomen ### wir haben an in beiden | so grozen schaden genomen ### den nimmer veberwindent | ir livte vnd ovh ir lant ### di rvedegeres helde | sint vnser ellenden pfant
###### 2223 | ### owe mines brvder | der tot ist hi gefrvmt ### waz mir der leiden maere | zallen ziten chvmt ### ovh mvoz mich immer riwen | der edel rvedger ### der schade ist beidenthalben | vnt div vil groezlichen ser
###### 2224 | ### do giselher der herre | sach sinen sweher tot ### di do darinne waren | di mvsen liden not ### der tot der svchte sere | da sin gesinde was ### der von bechelaren | do langer einer niht genas
###### 2225 | ### do gventher vnde giselher | vnd ovch hagene ### danchwart vnde volker | di gvten degene ### di giengen da si fvnden | ligen di zwene man ### do wart da von den helden | mit iamer weinen getan
###### 2226 | ### der tot vns sere rovbet | sprach giselher daz chint ### nv lazet iwer weinen | vnd ge wir an den wint ### daz vns di ringe erchvlen | vns stritmveden man ### ia wen vns got von himele niht lenger | hi ce lebene gan
###### 2227 | ### den sizzen disen leinen | sah man manegen degen ### si waren aber mvezech | da waren tot gelegen ### di rvedegeres helde | vergangen was der doz ### so lange wert div stille | daz sin eceln verdroz
###### 2228 | ### owe dirre dieneste | sprach des chveneges wip ### di ne sint so staete | daz viende lip ### mvge des engelten | von rvedegeres hant ### er wil si wider bringen | in der bvergonden lant
###### 2229 | ### waz hilfet chvenech ecel | daz wir geteilet han ### mit im swaz er wolde | der helt hat missetan ### der vns da solde rechen | der wil der svne pflegen ### des antwurte volker | der vil zierliche degen
###### 2230 | ### de rede en ist niht so leider | vil edel chveneges wip ### getorste ich heizen liegen | alsus edelen lip ### so het ir tivuellichen | an rvedgeren gelogen ### er vnt di sinen degene | sint an der svne gar betrogen
###### 2231 | ### er tet so vollechliche | daz im der kvenech gebot ### daz er vnde sin gesinde | ist hi gelegen tot ### nv sehet alvmbe criemhilt | wem ir gebieten welt ### iv hat vnz vf den ende | gedienet rvedger der helt
###### 2232 | ### welt ir des niht gelovben | man solz sehen lan ### dvrch ir hercenleide | so wart do daz getan ### man trvch den helt verhowen | da in der chvenech sach ### den eceln degene | so rehte leide ni geschach
###### 2233 | ### do si den mragraven | sahen toten tragen ### ez en chvnde dehein schribaer | geprieven noch gesach ### di manege vngebaere | von wibe vnde ovh von man ### div sich von hercen iamer | alda zeigen began
###### 2234 | ### der eceln iamer | wart also groz ### als eines lewen stimme | der riche chvenech erdoz ### mit herceleidem wuffe | alsam tet ovch sin wip ### si klageten vngefvoge | des gvten rvdegeres lip

<<< Übersicht <<< vorige Seite nächste Seite >>>